@@ -274,13 +274,13 @@ void analyze_argument(const int argc, char **argv, OPArg *oparg)
 	}
 */
 	oparg->argc = argc;
-	oparg->fromindex = optind;
-	oparg->toindex = argc - 1;
+	oparg->src_index = optind;
+	oparg->dst_index = argc - 1;
 	oparg->argv = argv;
 
 	/* コピー元の数をチェック */
 	{
-		off_t index_tmp = oparg->toindex;
+		off_t index_tmp = oparg->dst_index;
 		off_t count_tmp = 0;
 		for(int tmp = optind; tmp < index_tmp; tmp++)
 		{
