@@ -55,6 +55,8 @@
 	}\
 	else \
 	{\
+		/* signalハンドラ用 */\
+		write_now = cpinfo->dst;\
 		open_dst = true;\
 		cpdd->mk_file_count++;\
 	}\
@@ -238,9 +240,6 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 	cpinfo->src_size = 0;
 	cpinfo->dst_size = 0;
 
-	/* signalハンドラ用 */
-	write_now = cpinfo->dst;
-
 	errno = 0;
 	if((isrc = open(cpinfo->src, O_RDONLY | O_NOATIME | O_NOFOLLOW)) == -1)
 	{
