@@ -69,6 +69,11 @@ int main(int argc, char **argv)
 	VList *drive_list = get_drive_list();
 	set_signal();
 
+	#ifdef _DEBUG_FLAG
+		puts("Debug modeで動作しています...");
+		fflush(stdout);
+	#endif
+
 	puts("コピーを開始します...");
 	fflush(stdout);
 
@@ -87,7 +92,7 @@ int main(int argc, char **argv)
 		do_compare_verify_two(oparg, file_list, sdir, cpdd);
 
 		puts("ハッシュ値のチェックを完了しました...");
-			fflush(stdout);
+		fflush(stdout);
 	}
 
 	if(oparg->M == MOVE)
@@ -154,24 +159,25 @@ int main(int argc, char **argv)
 			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->src);\
 		}\
 	}\
+\
+	cpinfo->s_para = UNLINK;\
 }
 
 /*******************************************************************************
 *******************************************************************************/
 #define HASH_CHECK \
 {\
-	if(cpinfo->write == true)\
+	if(cpinfo->d_para == WRITE)\
 	{\
 		compare_hash(oparg, sdir, cpinfo, cpdd);\
 \
 		if((oparg->M == MOVE) && (cpinfo->hash_check == true))\
 		{\
 			FILE_REMOVE\
-			cpinfo->write = false;\
 		}\
 \
 	}\
-	else if((cpinfo->write == false) && (cpinfo->skip == false))\
+	else if(cpinfo->d_para != SKIP)\
 	{\
 		fprintf(stderr, "ファイルの書き込みに失敗しているため、コンペアをスキップします\n");\
 		fprintf(stderr, "src : %s\n", cpinfo->src);\
@@ -208,6 +214,10 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 			case V_FIVE:
 				if(cpinfo->verify_md5 == NULL)
 				{
+					/*
+					 * コピーを実行していればsrc_sizeは0以上に、
+					 * していなければ0になっている。
+					*/
 					if(cpinfo->src_size > 0)
 					{
 						fprintf(stderr, "ベリファイをスキップします\n");
@@ -215,6 +225,7 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 					}
 					else if(cpinfo->src_size < 0)
 					{
+						/* ここが実行されることは無い */
 						fprintf(stderr, "コピー元のファイサイズが不正です\n");
 						fprintf(stderr, "ベリファイをスキップします\n");
 						fprintf(stderr, "dst : %s\n", cpinfo->dst);
@@ -227,7 +238,6 @@ static inline void do_compare_verify_two(const OPArg *oparg, const VList *file_l
 					if((oparg->M == MOVE) && (cpinfo->hash_check == true))
 					{
 						FILE_REMOVE
-						cpinfo->write = false;
 					}
 				}
 				break;
@@ -271,18 +281,18 @@ static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *
 		case REGULAR:
 			if(oparg->CHECK == NOT)
 			{
-				if((cpinfo->write == true) && (cpinfo->src_size == cpinfo->dst_size))
+				if((cpinfo->d_para == WRITE) && (cpinfo->src_size <= cpinfo->dst_size))
 				{
 					FILE_REMOVE
 				}
 			}
 			else
 			{
-				if((cpinfo->hash_check == true) && (cpinfo->write == true) && (cpinfo->src_size == cpinfo->dst_size))
+				if((cpinfo->hash_check == true) && (cpinfo->d_para == WRITE) && (cpinfo->s_para != UNLINK) && (cpinfo->src_size <= cpinfo->dst_size))
 				{
 					FILE_REMOVE
 				}
-				else if((cpinfo->write == true) && (cpinfo->src_size == 0) && (cpinfo->dst_size == 0))
+				else if((cpinfo->d_para == WRITE) && (cpinfo->s_para != UNLINK) && (cpinfo->src_size == 0) && (cpinfo->dst_size == 0))
 				{
 					FILE_REMOVE
 				}
@@ -290,7 +300,7 @@ static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *
 			break;
 
 		case SYMBOLICLINK:
-			if(cpinfo->write == true)
+			if(cpinfo->d_para == WRITE)
 			{
 				FILE_REMOVE
 			}
