@@ -37,7 +37,7 @@ static _Bool read_finish;
 #define UNLINK_MISS_FILE \
 	print_error("NODATA", __FILE__, __LINE__, cpdd);\
 	write_log_hash_check(cpinfo, cpinfo->verify_md5, hex_output, sdir, cpdd, false);\
-	cpinfo->write = false;\
+	cpinfo->d_para = DELETE;\
 \
 	errno = 0;\
 	if(unlink(cpinfo->dst) == -1)\
@@ -195,7 +195,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 			fprintf(stderr, "メモリの確保に失敗しました\n");
 			print_error("NODATA", __FILE__, __LINE__, cpdd);
 			write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
-			cpinfo->write = false;
+			cpinfo->d_para = INITIAL;
 			break;
 		}
 	}
@@ -205,7 +205,7 @@ void verify_hash(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpd
 		fprintf(stderr, "%sをオープン出来ません\n", cpinfo->dst);
 		print_error("NODATA", __FILE__, __LINE__, cpdd);
 		write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
-		cpinfo->write = false;
+		cpinfo->d_para = INITIAL;
 	}
 
 	if(open_flag == true)
